@@ -28,6 +28,8 @@ def gitInitAndPush(dstToken, repoPath, chunkGroupRepoPath):
     git lfs track "*.webm"
     git lfs track "*.mkv"
     git lfs track "*.srt"
+    git lfs track "*.*"
+    git lfs track "*"
     git add .gitattributes
     '''
     cmd2 = f'''
